// Calendario e barra delle prenotazioni
jQuery(document).ready(function($) {
	var slopeWidgetsMinDays = $("#slope-widgets-config").data("min-days");
	if (slopeWidgetsMinDays == '' || slopeWidgetsMinDays <= '0') {
		slopeWidgetsMinDays = 1;
	}

	$("#arrival").datepicker({
		dateFormat: "dd/mm/yy",
		minDate: 0,
		onSelect: function(date) {
			var date2 = $('#arrival').datepicker('getDate');
			date2.setDate(date2.getDate() + slopeWidgetsMinDays);
			$('#departure').datepicker('setDate', date2);
			//sets minDate to dt1 date + 1
			$('#departure').datepicker('option', 'minDate', date2);
		}
	});
	$('#departure').datepicker({
		dateFormat: "dd/mm/yy",
		onClose: function() {
			var dt1 = $('#arrival').datepicker('getDate');
			var dt2 = $('#departure').datepicker('getDate');
			if (dt2 <= dt1) {
				var minDate = $('#departure').datepicker('option', 'minDate');
				$('#departure').datepicker('setDate', minDate);
			}
		}
	});
	$("#arrival").datepicker('setDate', '0');
	$("#departure").datepicker('setDate', slopeWidgetsMinDays);

	$.datepicker.regional['it'] = {
		closeText: 'Chiudi',
		currentText: 'Oggi',
		monthNames: ['Gennaio', 'Febbraio', 'Marzo', 'Aprile', 'Maggio', 'Giugno', 'Luglio', 'Agosto', 'Settembre', 'Ottobre', 'Novembre', 'Dicembre'],
		monthNamesShort: ['Gen', 'Feb', 'Mar', 'Apr', 'Mag', 'Giu', 'Lug', 'Ago', 'Set', 'Ott', 'Nov', 'Dic'],
		dayNames: ['Domenica', 'Luned&#236', 'Marted&#236', 'Mercoled&#236', 'Gioved&#236', 'Venerd&#236', 'Sabato'],
		dayNamesShort: ['Dom', 'Lun', 'Mar', 'Mer', 'Gio', 'Ven', 'Sab'],
		dayNamesMin: ['Do', 'Lu', 'Ma', 'Me', 'Gio', 'Ve', 'Sa'],
		dateFormat: "dd/mm/yy"
	};

	var slopeWidgetsLanguage = $("#slope-widgets-config").data("language");
	if (slopeWidgetsLanguage != '') {
		$.datepicker.setDefaults($.datepicker.regional['lang', slopeWidgetsLanguage]);
	}

	// Personalization of calendar style
	var slopeWidgetsCalendarColor = $("#slope-widgets-config").data("calendar-color");
	if (slopeWidgetsCalendarColor != '') {
		$(".ui-datepicker").css({'color': slopeWidgetsCalendarColor, 'font-weight': 'bold'});
	}

	var slopeWidgetRangeButton = $("#slope-widgets-config").data("range_button");
	if (slopeWidgetRangeButton != '') {
		$(".slope-block .slope-stepper-container .increment-button").css('border-radius:', slopeWidgetRangeButton);
	}

	var slopeWidgetRangeButton = $("#slope-widgets-config").data("range_button");
	if (slopeWidgetRangeButton != '') {
		$(".slope-block .slope-stepper-container .increment-button").css('border-radius:', slopeWidgetRangeButton);
	}

	//Border_radius card Promotions
	var slopeWidgetBorderRadius = $("#slope-widgets-config").data("range_button");
	if (slopeWidgetBorderRadius != '') {
		$(".slp-column").css('border-radius:', slopeWidgetBorderRadius);
	}

	//Title size Promotions
	var slopeWidgetTitleSize = $("#slope-widgets-config").data("title_size");
	if (slopeWidgetTitleSize != '') {
		$("p.slp-column").css('font-size:', slopeWidgetTitleSize);
	}

	$(".datepicker").datepicker();

});


// Managment of stepper behavior
function incrementAdults() {
	var input = document.getElementById("adults");
	if (input.value <= 98) {
		input.value = parseInt(input.value) + 1;
	}
}

function decrementAdults() {
	var input = document.getElementById("adults");
	if (input.value >= 2) {
		input.value = parseInt(input.value) - 1;
	}
}

function incrementChildren() {
	var input = document.getElementById("children");
	if (input.value <= 98) {
		input.value = parseInt(input.value) + 1;
	}
}

function decrementChildren() {
	var input = document.getElementById("children");
	if (input.value >= 1) {
		input.value = parseInt(input.value) - 1;
	}
}

// Packages and promotions
/**
 * Widget object to isolate all the logic needed from a widget.
 */
var WidgetManager = (function() {

	/**
	 * Establishment ID for the widget instance.
	 * @var {string}
	 */
	var establishmentID;

	/**
	 * Domain. The default value gets overridden in testing scenarios (e.g. //test.booking.slope.it).
	 * @var {string}
	 */
	var domain;

	/**
	 * Language. The language in which the widget must be rendered.
	 */
	var language;

	/**
	 * Controller action representing the path fo the widget we want to retrieve.
	 * @var {string}
	 */
	var widgetAction = "search";

	return {

		/**
		 * Populates the Widget object, this function is sort of initializer ("constructor").
		 *
		 * @param {string} widgetEstablishmentID
		 * @param {string} widgetDomain
		 * @param {string} type - Accepted values: "promotions", "search"
		 * @param {string} lang - Can be empty
		 */
		create: function(widgetEstablishmentID, widgetDomain, type, lang) {

			establishmentID = widgetEstablishmentID;
			language = lang;
			domain = widgetDomain || "booking.slope.it";
			domain = "https://" + domain;
			switch (type) {
				case "promotions":
					widgetAction = "promotions";
					break;
				case "search":
				default:
					widgetAction = "search";
					break;
			}
		},

		/**
		 * Returns the url of the action that generates the JSONp for the desired widget.
		 *
		 * @returns {string}
		 */
		getWidgetUrl: function() {
			return domain + '/widgets/' + widgetAction + '/' + establishmentID + (language ? '/' + language : '');
		},

		/**
		 * Returns the full url to the css resource.
		 *
		 * @returns {string}
		 */
		getCSSResource: function() {
			return domain + "/css/widgets/slope.css";
		}
	};
})();

/**
 * Used to embed our promotions widget into external websites.
 * Dumped in a publicly accessible, easily readable URL (via Assetic `output` attribute).
 */
jQuery(document).ready(function($) {

	// Check if the member included the select promotion widget.
	if ($('#slope-promotions').length) {

		WidgetManager.create($('#slope-promotions').attr('data-id'), $('#slope-bl').attr('data-domain'), 'promotions');

		// The page might have more than 1 widget, include the css just once.
		if ($('#widget-css').length === 0) {
			$("head").append('<link id="widget-css" rel="stylesheet" type="text/css" href="' + WidgetManager.getCSSResource() + '" />');
		}

		$.get(WidgetManager.getWidgetUrl(), null, function(data) {
				$('#slope-promotions').html(data.html); // Inject HTML in the page.
			},
			'jsonp'
		);
	}
});
